@@ -36,6 +36,11 @@ class CalicoPlugin(Ml2Plugin, l3_db.L3_NAT_db_mixin):
         # Add the ability to handle floating IPs.
         self._supported_extension_aliases.extend(["router"])
 
+        # Suppress the Neutron server's DHCP agent scheduling.  This is useful
+        # because it suppresses many WARNING logs that would otherwise appear,
+        # but that are actually spurious in a Calico/OpenStack deployment.
+        self._supported_extension_aliases.remove("dhcp_agent_scheduler")
+
         # Set ML2 options so the user doesn't have to.
         LOG.info("Forcing ML2 mechanism_drivers to 'calico'")
         cfg.CONF.set_override('mechanism_drivers', ['calico'], group='ml2')
